package com.synhaptein.scalator.security

import java.security.MessageDigest

/**
 * HashService abstract class to extends in your application to support custom salted hash.
 * It provide a singleton and a setInstance to set a custom instance as a singleton.
 *
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright     Copyright 2010-2011, SynHaptein (http://www.synhaptein.com)
 * @link          http://www.synhaptein.com/Scalator scalator project
 * @since         scalator 0.1
 * @license       http://www.synhaptein.com/scalator/license.html
 */

object HashService {
  private val HEXES = "0123456789abcdef"  
  private var hashManager: HashService = new HashServiceImpl;

  def apply(): HashService = hashManager

  def setInstance(instance: HashService) = {
    hashManager = instance
  }

  def setAlgorithm(algorithm: String) = {
    hashManager.algorithm = algorithm
  }
}

abstract class HashService protected
{
  private var algorithm = "SHA-256"
  
  def hashString(string: String): String = {
    val digest = MessageDigest.getInstance(algorithm)
    digest.reset()
    byteArrayToString(digest.digest(addSalt(string).getBytes("UTF-8")))
  }

  protected def addSalt(string: String): String

  private def byteArrayToString(raw: Array[Byte]): String = {
    val hex = new StringBuilder( 2 * raw.length );
    for (val b <- raw) {
      hex.append(HashService.HEXES.charAt((b & 0xF0) >> 4))
         .append(HashService.HEXES.charAt((b & 0x0F)));
    }
    hex.toString();
  }
}