package com.synhaptein.scalator.security

import com.synhaptein.scalator.context.Context

/**
 * The userService offer basic operations on user such as login, create or save.
 *
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright     Copyright 2010-2011, SynHaptein (http://www.synhaptein.com)
 * @link          http://www.synhaptein.com/scalator scalator project
 * @since         scalator 0.1
 * @license       http://www.synhaptein.com/scalator/license.html
 */

object UserService
{
  val USER = classOf[User].getName;
  var userRepo: UserRepository = null

  def setInstance(userRepo: UserRepository) = {
    this.userRepo = userRepo
  }
}

class UserService(val context: Context)
{
  def login(username: String, plainPassword: String): Option[User] = {
    val user = UserService.userRepo.find(username)
    user match {
      case None => return None
      case Some(u) =>
        if (u.getPassword.equals(HashService().hashString(plainPassword))) {
          register(u)
          return Some(u)
        }
        else {
          return None
        }
    }
  }

  def register(user: User) = {
    context.session(UserService.USER) = user
  }

  def unregister(user: User) = {
    context.session(UserService.USER) = null
  }

  def getUser(): Option[User] = {
    val user = context.session(UserService.USER)
    user match {
      case None => return None
      case Some(u) => return Some(u.asInstanceOf[User])
    }
  }

  def save(user: User) = {
    if(user.getId.size > 0) {
      UserService.userRepo.update(user)
    }
    else {
      UserService.userRepo.create(user)
    }
  }
}